MiniJSON
========

[![Build Status](https://travis-ci.com/Dronehub/minijson.svg)](https://travis-ci.com/Dronehub/minijson)
[![Test Coverage](https://api.codeclimate.com/v1/badges/34b392b61482d98ad3f0/test_coverage)](https://codeclimate.com/github/Dronehub/minijson/test_coverage)
[![Issue Count](https://codeclimate.com/github/Dronehub/minijson/badges/issue_count.svg)](https://codeclimate.com/github/Dronehub/minijson)
[![Documentation Status](https://readthedocs.org/projects/minijson/badge/?version=latest)](http://minijson.readthedocs.io/en/latest/?badge=latest)
[![PyPI](https://img.shields.io/pypi/pyversions/minijson.svg)](https://pypi.python.org/pypi/minijson)
[![PyPI version](https://badge.fury.io/py/minijson.svg)](https://badge.fury.io/py/minijson)
[![PyPI](https://img.shields.io/pypi/implementation/minijson.svg)](https://pypi.python.org/pypi/minijson)
[![PyPI](https://img.shields.io/pypi/wheel/minijson.svg)]()
[![License](https://img.shields.io/pypi/l/minijson)](https://github.com/Dronehub/minijson)


MiniJSON is a codec for a compact binary representation of a superset of JSON (binary values)
are supported.

Usage
-----

Refer to the [documentation](http://minijson.readthedocs.io/en/latest/?badge=latest)
for use.

If there are no binary wheels precompiled for this platform, you will need to
compile it yourself.
Alternatively, you can
[file an issue](https://github.com/Dronehub/minijson/issues/new)
and I'll do my best to compile a wheel for you.

In order to do that you must have `Cython` installed.
